// qjackctlPatchbayFile.h
//
/****************************************************************************
   Copyright (C) 2003-2007, rncbc aka Rui Nuno Capela. All rights reserved.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

*****************************************************************************/

#ifndef __qjackctlPatchbayFile_h
#define __qjackctlPatchbayFile_h

#include "qjackctlPatchbayRack.h"


// Patchbay XML definition.
class qjackctlPatchbayFile
{
public:

	// Simple patchbay I/O methods.
	static bool load (qjackctlPatchbayRack *pPatchbay,
		const QString& sFilename);
	static bool save (qjackctlPatchbayRack *pPatchbay,
		const QString& sFilename);
};


#endif  // __qjackctlPatchbayFile_h

// qjackctlPatchbayFile.h
